@@ -34,6 +34,7 @@
 #include <QDBusPendingCall>
 #include <QGuiApplication>
 #include <QX11Info>
+#include <QTimer>
 #include <QDebug>
 
 #include <KActionCollection>
@@ -42,6 +43,7 @@
 #include <KLocalizedString>
 #include <KPluginFactory>
 #include <KSharedConfig>
+#include <TabletModeWatcher>
 
 namespace PowerDevil {
 namespace BundledActions {
@@ -68,19 +70,11 @@ DPMS::DPMS(QObject* parent)
     // inhibitions persist over kded module unload/load
     m_inhibitScreen = PowerDevil::PolicyAgent::instance()->unavailablePolicies() & PowerDevil::PolicyAgent::ChangeScreenSettings;
 
-    KGlobalAccel *accel = KGlobalAccel::self();
-
     KActionCollection *actionCollection = new KActionCollection( this );
     actionCollection->setComponentDisplayName(i18nc("Name for powerdevil shortcuts category", "Power Management"));
 
     QAction *globalAction = actionCollection->addAction(QLatin1String("Turn Off Screen"));
     globalAction->setText(i18nc("@action:inmenu Global shortcut", "Turn Off Screen"));
-    const bool mobile = !qEnvironmentVariableIsEmpty("QT_QUICK_CONTROLS_MOBILE");
-    if (!mobile) {
-        accel->setGlobalShortcut(globalAction, QList<QKeySequence>());
-    } else {
-        accel->setGlobalShortcut(globalAction, Qt::Key_PowerOff);
-    }
     connect(globalAction, &QAction::triggered, this, [this] {
         if (m_helper) {
             if (m_lockBeforeTurnOff) {
@@ -89,6 +83,17 @@ DPMS::DPMS(QObject* parent)
             m_helper->trigger(QStringLiteral("TurnOff"));
         }
     });
+
+    auto powerButtonMode = [globalAction] (bool isTablet) {
+        if (!isTablet) {
+            KGlobalAccel::self()->setGlobalShortcut(globalAction, QList<QKeySequence>());
+        } else {
+            KGlobalAccel::self()->setGlobalShortcut(globalAction, Qt::Key_PowerOff);
+        }
+    };
+    auto interface = Kirigami::TabletModeWatcher::self();
+    connect(interface, &Kirigami::TabletModeWatcher::tabletModeChanged, globalAction, powerButtonMode);
+    powerButtonMode(interface->isTabletMode());
 }
 
 DPMS::~DPMS() = default;
@@ -212,12 +217,21 @@ void DPMS::onUnavailablePoliciesChanged(PowerDevil::PolicyAgent::RequiredPolicie
     }
 }
 
+static std::chrono::milliseconds dimAnimationTime()
+{
+    // See kscreen.kcfg from kwin
+    return std::chrono::milliseconds (KSharedConfig::openConfig("kwinrc")->group("Effect-Kscreen").readEntry("Duration", 250));
+}
+
 void DPMS::lockScreen()
 {
-    QDBusConnection::sessionBus().asyncCall(QDBusMessage::createMethodCall("org.freedesktop.ScreenSaver",
-                                                                           "/ScreenSaver",
-                                                                           "org.freedesktop.ScreenSaver",
-                                                                           "Lock"));
+    // We need to delay locking until the screen has dimmed, otherwise it looks all clunky
+    QTimer::singleShot(dimAnimationTime(), [] {
+        QDBusConnection::sessionBus().asyncCall(QDBusMessage::createMethodCall("org.freedesktop.ScreenSaver",
+                                                                            "/ScreenSaver",
+                                                                            "org.freedesktop.ScreenSaver",
+                                                                            "Lock"));
+    });
 }
 
 }
