@@ -27,6 +27,7 @@
 #include <powerdevilpowermanagement.h>
 
 #include <powerdevil_debug.h>
+#include <TabletModeWatcher>
 
 #include <QCheckBox>
 #include <QFormLayout>
@@ -56,7 +57,7 @@ K_PLUGIN_FACTORY(PowerDevilProfilesKCMFactory,
                 )
 
 EditPage::EditPage(QWidget *parent, const QVariantList &args)
-        : KCModule(nullptr, parent, args)
+        : KCModule(parent, args)
 {
     setButtons(Apply | Help | Default);
 
@@ -77,15 +78,17 @@ EditPage::EditPage(QWidget *parent, const QVariantList &args)
     m_profilesConfig = KSharedConfig::openConfig("powermanagementprofilesrc", KConfig::SimpleConfig | KConfig::CascadeConfig);
 
     if (m_profilesConfig->groupList().isEmpty()) {
-        // Use the generator
+        auto interface = Kirigami::TabletModeWatcher::self();
+
         PowerDevil::ProfileGenerator::generateProfiles(
+            interface->isTabletModeAvailable(),
             PowerDevil::PowerManagement::instance()->canSuspend(),
             PowerDevil::PowerManagement::instance()->canHibernate()
         );
         m_profilesConfig->reparseConfiguration();
     }
 
-    qCDebug(POWERDEVIL) << m_profilesConfig.data()->groupList() << m_profilesConfig.data()->entryMap().keys();
+    qCDebug(POWERDEVIL) << "loaded profiles" << m_profilesConfig.data()->groupList() << m_profilesConfig.data()->entryMap().keys();
 
     // Create widgets for each profile
     ActionEditWidget *editWidget = new ActionEditWidget("AC", tabWidget);
@@ -194,7 +197,10 @@ void EditPage::restoreDefaultProfiles()
                                                             "Are you sure you want to continue?"), i18n("Restore Default Profiles"));
     if (ret == KMessageBox::Continue) {
         qCDebug(POWERDEVIL) << "Restoring defaults.";
+        auto interface = Kirigami::TabletModeWatcher::self();
+
         PowerDevil::ProfileGenerator::generateProfiles(
+            interface->isTabletModeAvailable(),
             PowerDevil::PowerManagement::instance()->canSuspend(),
             PowerDevil::PowerManagement::instance()->canHibernate()
         );
